@@ -6,7 +6,7 @@ import (
 	"io"
 	"strconv"
 
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/commands/mr/mrutils"
@@ -52,14 +52,22 @@ func NewCmdGet(f *cmdutils.Factory) *cobra.Command {
 
 			// Parse arguments into local vars
 			branch, _ := cmd.Flags().GetString("branch")
-			if branch == "" {
-				branch, err = git.CurrentBranch()
-				if err != nil {
-					return err
-				}
-			}
 			pipelineId, err := cmd.Flags().GetInt("pipeline-id")
-			if err != nil || pipelineId == 0 {
+			if err != nil {
+				return err
+			}
+
+			var msgNotFound string
+			if pipelineId != 0 {
+				msgNotFound = fmt.Sprintf("No pipeline with the given ID: %d", pipelineId)
+			} else {
+				if branch == "" {
+					branch, err = git.CurrentBranch()
+					if err != nil {
+						return err
+					}
+				}
+
 				commit, err := api.GetCommit(apiClient, repo.FullName(), branch)
 				if err != nil {
 					return err
@@ -82,12 +90,13 @@ func NewCmdGet(f *cmdutils.Factory) *cobra.Command {
 				} else {
 					pipelineId = commit.LastPipeline.ID
 				}
+				msgNotFound = fmt.Sprintf("No pipelines running or available on branch: %s", branch)
 			}
 
 			pipeline, err := api.GetPipeline(apiClient, pipelineId, nil, repo.FullName())
 			if err != nil {
 				redCheck := c.Red("✘")
-				fmt.Fprintf(f.IO.StdOut, "%s No pipelines running or available on branch: %s\n", redCheck, branch)
+				fmt.Fprintf(f.IO.StdOut, "%s %s\n", redCheck, msgNotFound)
 				return err
 			}
 
@@ -125,7 +134,7 @@ func NewCmdGet(f *cmdutils.Factory) *cobra.Command {
 		},
 	}
 
-	pipelineGetCmd.Flags().StringP("branch", "b", "", "Check pipeline status for a branch. (Default: current branch)")
+	pipelineGetCmd.Flags().StringP("branch", "b", "", "Check pipeline status for a branch. (default current branch)")
 	pipelineGetCmd.Flags().IntP("pipeline-id", "p", 0, "Provide pipeline ID.")
 	pipelineGetCmd.Flags().StringP("output", "F", "text", "Format output. Options: text, json.")
 	pipelineGetCmd.Flags().StringP("output-format", "o", "text", "Use output.")
