@@ -6,7 +6,7 @@ import (
 
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/commands/mr/mrutils"
@@ -24,14 +24,16 @@ var mrCheckoutCfg mrCheckoutConfig
 func NewCmdCheckout(f *cmdutils.Factory) *cobra.Command {
 	mrCheckoutCmd := &cobra.Command{
 		Use:   "checkout [<id> | <branch>]",
-		Short: "Checkout to an open merge request",
+		Short: "Check out an open merge request.",
 		Long:  ``,
 		Example: heredoc.Doc(`
-			glab mr checkout 1
-			glab mr checkout branch
-			glab mr checkout 12 --branch todo-fix
-			glab mr checkout new-feature --set-upstream-to=upstream/main
-			glab mr checkout   # use checked out branch
+			$ glab mr checkout 1
+			$ glab mr checkout branch
+			$ glab mr checkout 12 --branch todo-fix
+			$ glab mr checkout new-feature --set-upstream-to=upstream/main
+
+			# Uses the checked-out branch
+			$ glab mr checkout
 		`),
 		Args: cobra.ExactArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -107,7 +109,9 @@ func NewCmdCheckout(f *cmdutils.Factory) *cobra.Command {
 			}
 
 			// Check out branch
-			if err := git.CheckoutBranch(mrCheckoutCfg.branch); err != nil {
+			var gr git.StandardGitCommand
+
+			if err := git.CheckoutBranch(mrCheckoutCfg.branch, gr); err != nil {
 				return err
 			}
 
@@ -120,9 +124,9 @@ func NewCmdCheckout(f *cmdutils.Factory) *cobra.Command {
 			return nil
 		},
 	}
-	mrCheckoutCmd.Flags().StringVarP(&mrCheckoutCfg.branch, "branch", "b", "", "checkout merge request with <branch> name")
-	mrCheckoutCmd.Flags().BoolVarP(&mrCheckoutCfg.track, "track", "t", true, "set checked out branch to track remote branch")
+	mrCheckoutCmd.Flags().StringVarP(&mrCheckoutCfg.branch, "branch", "b", "", "Check out merge request with name <branch>.")
+	mrCheckoutCmd.Flags().BoolVarP(&mrCheckoutCfg.track, "track", "t", true, "Set checked out branch to track the remote branch.")
 	_ = mrCheckoutCmd.Flags().MarkDeprecated("track", "Now enabled by default")
-	mrCheckoutCmd.Flags().StringVarP(&mrCheckoutCfg.upstream, "set-upstream-to", "u", "", "set tracking of checked out branch to [REMOTE/]BRANCH")
+	mrCheckoutCmd.Flags().StringVarP(&mrCheckoutCfg.upstream, "set-upstream-to", "u", "", "Set tracking of checked-out branch to [REMOTE/]BRANCH.")
 	return mrCheckoutCmd
 }
