@@ -14,15 +14,18 @@ import (
 func NewCmdRevoke(f *cmdutils.Factory) *cobra.Command {
 	mrRevokeCmd := &cobra.Command{
 		Use:     "revoke [<id> | <branch>]",
-		Short:   `Revoke approval on a merge request`,
+		Short:   `Revoke approval on a merge request.`,
 		Long:    ``,
 		Aliases: []string{"unapprove"},
 		Example: heredoc.Doc(`
-			glab mr revoke 123
-			glab mr unapprove 123
-			glab mr revoke branch
-			glab mr revoke  # use checked out branch
-			glab mr revoke 123 branch 456
+			$ glab mr revoke 123
+			$ glab mr unapprove 123
+			$ glab mr revoke branch
+
+			# Uses the checked-out branch
+			$ glab mr revoke
+
+			$ glab mr revoke 123 branch 456
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
@@ -40,21 +43,21 @@ func NewCmdRevoke(f *cmdutils.Factory) *cobra.Command {
 
 			for _, mr := range mrs {
 				if err = mrutils.MRCheckErrors(mr, mrutils.MRCheckErrOptions{
-					WorkInProgress: true,
-					Closed:         true,
-					Merged:         true,
+					Draft:  true,
+					Closed: true,
+					Merged: true,
 				}); err != nil {
 					return err
 				}
 
-				fmt.Fprintf(f.IO.StdOut, "- Revoking approval for Merge Request !%d...\n", mr.IID)
+				fmt.Fprintf(f.IO.StdOut, "- Revoking approval for merge request !%d...\n", mr.IID)
 
 				err = api.UnapproveMR(apiClient, repo.FullName(), mr.IID)
 				if err != nil {
 					return err
 				}
 
-				fmt.Fprintln(f.IO.StdOut, c.GreenCheck(), "Merge Request approval revoked")
+				fmt.Fprintln(f.IO.StdOut, c.GreenCheck(), "Merge request approval revoked.")
 			}
 
 			return nil
