@@ -14,14 +14,16 @@ import (
 func NewCmdSubscribe(f *cmdutils.Factory) *cobra.Command {
 	mrSubscribeCmd := &cobra.Command{
 		Use:     "subscribe [<id> | <branch>]",
-		Short:   `Subscribe to merge requests`,
+		Short:   `Subscribe to a merge request.`,
 		Long:    ``,
 		Aliases: []string{"sub"},
 		Example: heredoc.Doc(`
-			glab mr subscribe 123
-			glab mr sub 123
-			glab mr subscribe branch
-			glab mr subscribe 123 branch  # subscribe to multiple MRs
+			$ glab mr subscribe 123
+			$ glab mr sub 123
+			$ glab mr subscribe branch
+
+			# Subscribe to multiple merge requests
+			$ glab mr subscribe 123 branch
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
@@ -44,15 +46,15 @@ func NewCmdSubscribe(f *cmdutils.Factory) *cobra.Command {
 					return err
 				}
 
-				fmt.Fprintf(f.IO.StdOut, "- Subscribing to merge request !%d\n", mr.IID)
+				fmt.Fprintf(f.IO.StdOut, "- Subscribing to merge request !%d.\n", mr.IID)
 
 				mr, err = api.SubscribeToMR(apiClient, repo.FullName(), mr.IID, nil)
 				if err != nil {
 					return err
 				}
 
-				fmt.Fprintf(f.IO.StdOut, "%s You have successfully subscribed to merge request !%d\n", c.GreenCheck(), mr.IID)
-				fmt.Fprintln(f.IO.StdOut, mrutils.DisplayMR(c, mr, f.IO.IsaTTY))
+				fmt.Fprintf(f.IO.StdOut, "%s You have successfully subscribed to merge request !%d.\n", c.GreenCheck(), mr.IID)
+				fmt.Fprintln(f.IO.StdOut, mrutils.DisplayMR(c, &mr.BasicMergeRequest, f.IO.IsaTTY))
 			}
 
 			return nil
