@@ -6,15 +6,17 @@ import (
 
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/briandowns/spinner"
+
 	"gitlab.com/gitlab-org/cli/internal/run"
 	"gitlab.com/gitlab-org/cli/pkg/git"
 	"gitlab.com/gitlab-org/cli/pkg/text"
 
 	"github.com/spf13/cobra"
+
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 )
 
-func NewCmdAmendStack(f *cmdutils.Factory, getText cmdutils.GetTextUsingEditor) *cobra.Command {
+func NewCmdAmendStack(f *cmdutils.Factory, gr git.GitRunner, getText cmdutils.GetTextUsingEditor) *cobra.Command {
 	stackSaveCmd := &cobra.Command{
 		Use:   "amend",
 		Short: `Save more changes to a stacked diff. (EXPERIMENTAL.)`,
@@ -56,7 +58,7 @@ func amendFunc(f *cmdutils.Factory, args []string, getText cmdutils.GetTextUsing
 		return "", fmt.Errorf("error running Git command: %v", err)
 	}
 
-	ref, err := git.CurrentStackRefFromBranch(title)
+	ref, err := git.CurrentStackRefFromCurrentBranch(title)
 	if err != nil {
 		return "", fmt.Errorf("error checking for stack: %v", err)
 	}
