@@ -16,7 +16,7 @@ import (
 
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
@@ -216,7 +216,7 @@ func createTokenRun(opts *CreateOptions) error {
 			if err != nil {
 				return err
 			}
-			listOptions := &gitlab.ListProjectAccessTokensOptions{PerPage: 100}
+			listOptions := &gitlab.ListProjectAccessTokensOptions{ListOptions: gitlab.ListOptions{PerPage: 100}}
 			tokens, err := api.ListProjectAccessTokens(httpClient, repo.FullName(), listOptions)
 			if err != nil {
 				return err
@@ -251,7 +251,7 @@ func createTokenRun(opts *CreateOptions) error {
 			return err
 		}
 	} else {
-		if _, err := opts.IO.StdOut.Write([]byte(outputTokenValue)); err != nil {
+		if _, err := fmt.Fprintf(opts.IO.StdOut, "%s\n", outputTokenValue); err != nil {
 			return err
 		}
 	}
