@@ -1,14 +1,18 @@
 package git
 
 import (
+	"errors"
+	"os"
 	"path"
+	"path/filepath"
 	"slices"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"gitlab.com/gitlab-org/cli/internal/config"
-	"gitlab.com/gitlab-org/cli/internal/run"
+	git_testing "gitlab.com/gitlab-org/cli/pkg/git/testing"
+	"go.uber.org/mock/gomock"
 )
 
 func Test_StackRemoveRef(t *testing.T) {
@@ -93,20 +97,19 @@ func Test_StackRemoveRef(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			dir := InitGitRepoWithCommit(t)
 
-			err := createRefFiles(tt.args.stack.Refs, tt.args.stack.Title)
+			ctrl := gomock.NewController(t)
+			mockCmd := git_testing.NewMockGitRunner(ctrl)
+
+			if tt.args.remove.Prev != "" {
+				prevBranch := tt.args.stack.Refs[tt.args.remove.Prev].Branch
+				mockCmd.EXPECT().Git([]string{"checkout", prevBranch}).Return("main", nil)
+				mockCmd.EXPECT().Git([]string{"branch", "-D", tt.args.remove.Branch})
+			}
+
+			err := CreateRefFiles(tt.args.stack.Refs, tt.args.stack.Title)
 			require.Nil(t, err)
 
-			branches := map[string]StackRef{}
-			branches[tt.args.remove.SHA] = tt.args.remove
-			if tt.args.remove.Prev != "" {
-				branches[tt.args.remove.Prev] = tt.args.stack.Refs[tt.args.remove.Prev]
-			}
-			CreateBranches(t, branches)
-
-			err = CheckoutBranch("main")
-			require.NoError(t, err)
-
-			err = tt.args.stack.RemoveRef(tt.args.remove)
+			err = tt.args.stack.RemoveRef(tt.args.remove, mockCmd)
 			require.Nil(t, err)
 
 			require.Equal(t, tt.expected, tt.args.stack.Refs)
@@ -117,6 +120,52 @@ func Test_StackRemoveRef(t *testing.T) {
 	}
 }
 
+func Test_AddStackBaseBranch(t *testing.T) {
+	tests := []struct {
+		name   string
+		title  string
+		branch string
+	}{
+		{
+			name:   "successfully add branch",
+			title:  "test-stack",
+			branch: "main",
+		},
+		{
+			name:   "successfully add custom branch",
+			title:  "custom-stack",
+			branch: "feature/branch",
+		},
+		{
+			name:   "successfully add custom branch",
+			title:  "custom-stack",
+			branch: "feature/branch",
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			InitGitRepo(t)
+
+			_, err := AddStackRefDir(tt.title)
+			require.NoError(t, err)
+
+			err = AddStackBaseBranch(tt.title, tt.branch)
+			require.NoError(t, err)
+
+			stackRoot, err := StackRootDir(tt.title)
+			require.NoError(t, err)
+
+			filename := filepath.Join(stackRoot, BaseBranchFile)
+			require.FileExists(t, filename)
+
+			content, err := os.ReadFile(filename)
+			require.NoError(t, err)
+			assert.Equal(t, tt.branch, string(content))
+		})
+	}
+}
+
 func Test_StackLast(t *testing.T) {
 	tests := []struct {
 		name     string
@@ -181,6 +230,89 @@ func Test_StackFirst(t *testing.T) {
 	}
 }
 
+func Test_StackBaseBranch(t *testing.T) {
+	tests := []struct {
+		name           string
+		title          string
+		setupFile      bool
+		branchInFile   string
+		mockRemoteShow string
+		gitError       error
+		expectedBranch string
+		expectedError  bool
+	}{
+		{
+			name:           "successfully read branch from file",
+			title:          "test-stack",
+			setupFile:      true,
+			branchInFile:   "custom-branch",
+			expectedBranch: "custom-branch",
+			expectedError:  false,
+		},
+		{
+			name:      "get default branch when file doesn't exist",
+			title:     "test-stack",
+			setupFile: false,
+			mockRemoteShow: `* remote origin
+		Fetch URL: https://gitlab.org/gitlab-org/cli.git
+		Push  URL: https://gitlab.org/gitlab-org/cli.git
+		HEAD branch: main
+		Remote branches:`,
+			expectedBranch: "main",
+			expectedError:  false,
+		},
+		{
+			name:          "error getting remote data",
+			title:         "test-stack",
+			setupFile:     false,
+			gitError:      errors.New("git command failed"),
+			expectedError: true,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			InitGitRepo(t)
+
+			stack := Stack{
+				Title: tt.title,
+				Refs:  make(map[string]StackRef),
+			}
+
+			ctrl := gomock.NewController(t)
+			mockGitRunner := git_testing.NewMockGitRunner(ctrl)
+
+			if tt.setupFile {
+				_, err := AddStackRefDir(tt.title)
+				require.NoError(t, err)
+
+				err = AddStackBaseBranch(tt.title, tt.branchInFile)
+				require.NoError(t, err)
+			} else {
+				if tt.gitError != nil {
+					mockGitRunner.EXPECT().
+						Git([]string{"remote", "show", DefaultRemote}).
+						Return("", tt.gitError)
+				} else {
+					mockGitRunner.EXPECT().
+						Git([]string{"remote", "show", DefaultRemote}).
+						Return(tt.mockRemoteShow, nil)
+				}
+			}
+
+			branch, err := stack.BaseBranch(mockGitRunner)
+
+			if tt.expectedError {
+				require.Error(t, err)
+				return
+			}
+
+			require.NoError(t, err)
+			assert.Equal(t, tt.expectedBranch, branch)
+		})
+	}
+}
+
 func Test_StackEmpty(t *testing.T) {
 	s := Stack{Refs: make(map[string]StackRef)}
 	if !s.Empty() {
@@ -195,10 +327,11 @@ func Test_StackEmpty(t *testing.T) {
 
 func Test_StackRemoveBranch(t *testing.T) {
 	tests := []struct {
-		name    string
-		stack   Stack
-		ref     StackRef
-		wantErr bool
+		name             string
+		stack            Stack
+		ref              StackRef
+		wantErr          bool
+		expectBaseBranch bool
 	}{
 		{
 			name: "remove single ref",
@@ -206,7 +339,8 @@ func Test_StackRemoveBranch(t *testing.T) {
 				Title: "test-stack",
 				Refs:  map[string]StackRef{"sha1": {SHA: "sha1", Branch: "branch123"}},
 			},
-			ref: StackRef{SHA: "sha1", Branch: "branch123"},
+			ref:              StackRef{SHA: "sha1", Branch: "branch123"},
+			expectBaseBranch: true,
 		},
 		{
 			name: "remove first ref",
@@ -217,7 +351,8 @@ func Test_StackRemoveBranch(t *testing.T) {
 					"sha2": {SHA: "sha2", Prev: "sha1", Branch: "branch456"},
 				},
 			},
-			ref: StackRef{SHA: "sha1", Next: "sha2", Branch: "branch123"},
+			ref:              StackRef{SHA: "sha1", Next: "sha2", Branch: "branch123"},
+			expectBaseBranch: true,
 		},
 		{
 			name: "remove middle ref",
@@ -229,7 +364,8 @@ func Test_StackRemoveBranch(t *testing.T) {
 					"sha3": {SHA: "sha3", Prev: "sha2", Branch: "branch789"},
 				},
 			},
-			ref: StackRef{SHA: "sha2", Prev: "sha1", Next: "sha3", Branch: "branch456"},
+			ref:              StackRef{SHA: "sha2", Prev: "sha1", Next: "sha3", Branch: "branch456"},
+			expectBaseBranch: false,
 		},
 		{
 			name: "remove last ref",
@@ -240,7 +376,8 @@ func Test_StackRemoveBranch(t *testing.T) {
 					"sha2": {SHA: "sha2", Prev: "sha1", Branch: "branch456"},
 				},
 			},
-			ref: StackRef{SHA: "sha2", Prev: "sha1", Branch: "branch456"},
+			ref:              StackRef{SHA: "sha2", Prev: "sha1", Branch: "branch456"},
+			expectBaseBranch: false,
 		},
 	}
 
@@ -248,24 +385,26 @@ func Test_StackRemoveBranch(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			InitGitRepoWithCommit(t)
 
-			gitAddRemote := GitCommand("remote", "add", "origin", "http://gitlab.com/gitlab-org/cli.git")
-			_, err := run.PrepareCmd(gitAddRemote).Output()
-			require.Nil(t, err)
+			ctrl := gomock.NewController(t)
+			mockCmd := git_testing.NewMockGitRunner(ctrl)
 
-			CreateBranches(t, tt.stack.Refs)
+			_, err := AddStackRefDir(tt.stack.Title)
+			require.NoError(t, err)
 
-			err = tt.stack.RemoveBranch(tt.ref)
+			err = AddStackBaseBranch(tt.stack.Title, "base")
+			require.NoError(t, err)
 
-			require.Nil(t, err)
-			if tt.wantErr {
-				require.Error(t, err)
+			if tt.ref.Prev != "" {
+				prevBranch := tt.stack.Refs[tt.ref.Prev].Branch
+				mockCmd.EXPECT().Git([]string{"checkout", prevBranch})
+				mockCmd.EXPECT().Git([]string{"branch", "-D", tt.ref.Branch})
 			} else {
-				require.Nil(t, err)
-
-				showref := GitCommand("show-ref", "--verify", "--quiet", "refs/heads/"+tt.ref.Branch)
-				_, err := run.PrepareCmd(showref).Output()
-				require.Error(t, err)
+				mockCmd.EXPECT().Git([]string{"checkout", "base"})
+				mockCmd.EXPECT().Git([]string{"branch", "-D", tt.ref.Branch})
 			}
+			//
+			err = tt.stack.RemoveBranch(tt.ref, mockCmd)
+			require.NoError(t, err)
 		})
 	}
 }
@@ -569,6 +708,76 @@ func Test_validateStackRefs(t *testing.T) {
 	}
 }
 
+func TestStack_IndexAt(t *testing.T) {
+	tests := []struct {
+		name     string
+		stack    Stack
+		ref      StackRef
+		expected int
+	}{
+		{
+			name: "Find existing ref in the middle",
+			stack: Stack{
+				Refs: map[string]StackRef{
+					"sha1": {SHA: "sha1", Branch: "branch1", Next: "sha2", Prev: ""},
+					"sha2": {SHA: "sha2", Branch: "branch2", Next: "sha3", Prev: "sha1"},
+					"sha3": {SHA: "sha3", Branch: "branch3", Next: "", Prev: "sha2"},
+				},
+			},
+			ref:      StackRef{SHA: "sha2", Branch: "branch2", Next: "sha3", Prev: "sha1"},
+			expected: 1,
+		},
+		{
+			name: "Find first ref",
+			stack: Stack{
+				Refs: map[string]StackRef{
+					"sha1": {SHA: "sha1", Branch: "branch1", Next: "sha2", Prev: ""},
+					"sha2": {SHA: "sha2", Branch: "branch2", Next: "", Prev: "sha1"},
+				},
+			},
+			ref:      StackRef{SHA: "sha1", Branch: "branch1", Next: "sha2", Prev: ""},
+			expected: 0,
+		},
+		{
+			name: "Find last ref",
+			stack: Stack{
+				Refs: map[string]StackRef{
+					"sha1": {SHA: "sha1", Branch: "branch1", Next: "sha2", Prev: ""},
+					"sha2": {SHA: "sha2", Branch: "branch2", Next: "sha3", Prev: "sha1"},
+					"sha3": {SHA: "sha3", Branch: "branch3", Next: "", Prev: "sha2"},
+				},
+			},
+			ref:      StackRef{SHA: "sha3", Branch: "branch3", Next: "", Prev: "sha2"},
+			expected: 2,
+		},
+		{
+			name: "Ref not found",
+			stack: Stack{
+				Refs: map[string]StackRef{
+					"sha1": {SHA: "sha1", Branch: "branch1", Next: "sha2", Prev: ""},
+					"sha2": {SHA: "sha2", Branch: "branch2", Next: "sha3", Prev: "sha1"},
+					"sha3": {SHA: "sha3", Branch: "branch3", Next: "", Prev: "sha2"},
+				},
+			},
+			ref:      StackRef{SHA: "sha4", Branch: "branch3"},
+			expected: -1,
+		},
+		{
+			name:     "Empty stack",
+			stack:    Stack{},
+			ref:      StackRef{SHA: "sha1", Branch: "branch1"},
+			expected: -1,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			result := tt.stack.IndexAt(tt.ref)
+			require.Equal(t, tt.expected, result)
+		})
+	}
+}
+
 func TestStack_Iter(t *testing.T) {
 	tests := []struct {
 		name               string
@@ -610,13 +819,62 @@ func TestStack_Iter(t *testing.T) {
 	}
 }
 
-func CreateBranches(t *testing.T, refs map[string]StackRef) {
-	// older versions of git could default to a different branch,
-	// so making sure this one exists.
-	_ = CheckoutNewBranch("main")
+func TestStack_Iter2(t *testing.T) {
+	type result struct {
+		index int
+		ref   StackRef
+	}
+	tests := []struct {
+		name     string
+		stack    Stack
+		expected []result
+	}{
+		{
+			name: "Empty stack",
+			stack: Stack{
+				Refs: map[string]StackRef{},
+			},
+			expected: []result{},
+		},
+		{
+			name: "Stack with multiple refs",
+			stack: Stack{
+				Refs: map[string]StackRef{
+					"sha1": {SHA: "sha1", Branch: "branch1", Prev: "", Next: "sha2"},
+					"sha2": {SHA: "sha2", Branch: "branch2", Prev: "sha1", Next: "sha3"},
+					"sha3": {SHA: "sha3", Branch: "branch3", Prev: "sha2", Next: ""},
+				},
+			},
+			expected: []result{
+				{0, StackRef{SHA: "sha1", Branch: "branch1", Next: "sha2"}},
+				{1, StackRef{SHA: "sha2", Branch: "branch2", Prev: "sha1", Next: "sha3"}},
+				{2, StackRef{SHA: "sha3", Branch: "branch3", Prev: "sha2"}},
+			},
+		},
+		{
+			name: "Stack with 1 ref",
+			stack: Stack{
+				Refs: map[string]StackRef{
+					"sha1": {SHA: "sha1", Branch: "branch1", Prev: "", Next: ""},
+				},
+			},
+			expected: []result{
+				{0, StackRef{SHA: "sha1", Branch: "branch1", Next: ""}},
+			},
+		},
+	}
 
-	for _, ref := range refs {
-		err := CheckoutNewBranch(ref.Branch)
-		require.Nil(t, err)
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			results := []result{}
+
+			for i, v := range tt.stack.Iter2() {
+				assert.Equal(t, i, tt.expected[i].index)
+				assert.Equal(t, v, tt.expected[i].ref)
+				results = append(results, result{i, v})
+			}
+
+			assert.Equal(t, tt.expected, results)
+		})
 	}
 }
